/**
 * 组织生活表
 * organizationalLife
 */

import { Schema } from "mongoose";
import {yfsDB} from '../db/dbInit';
var autoIncrement = require('mongoose-auto-increment');

const organizationalLifeSchema = new Schema({
    oId: {type:Number, index:{unique: true}}, //自增的活动id
    partyActivityType: Number, //党建活动类型 1：日常教育培训、2：主题党日活动、3：骨干队伍培训、4：支部工作会、5：二十大精神、6：三会一课
    activityStartTime: {type:Number, index:true}, //活动开始时间
    activityEndTime:{type:Number, index:true}, //活动结束时间
    activityAdd: String, //活动地点
    activityHost: {type:[String], default:[]}, //活动主持人
    activityNoteTaker:{type:[String], default:[]}, //活动记录人
    leavePartyMember:{type:[String], default:[]}, //请假党员 非必填
    participatingPartyMember:{type:[String], default:[]}, //参与党员
    participationRecord:String, //活动记录
    branchName: Number, //支部名称

})

var organizationalLifeModel;

export function initModel(){
    organizationalLifeSchema.plugin(autoIncrement.plugin, {
        model: 'organizationalLifeSchema',
        field: 'oId',
        startAt: 1, //初始化id从1开始
        incrementBy: 1 //每次自增1
    });

    organizationalLifeModel = yfsDB.model('organizationalLife', organizationalLifeSchema);

    organizationalLifeModel.selectOnceData = async function (paramater:object) {
        let selectInfo = await organizationalLifeModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo)
            }
        }

        return selectInfo;
    }

}


export async function save(throwError=false) {
    if (!this.isModified()) return;
    await this.runSave({validateBeforeSave:false}).catch(err=>{
        console.log(err);
    });
}
 

/**
 * 获取符合条件的组织生活列表
 * @param param 查询参数
 * @returns 
 */
export async function findOrganizationalLifeList(param:object) {
    return await organizationalLifeModel.find(param);
}


/**
 * 创建活动
 * @param param 所添加表单 需要提前验证
 */
export async function createActivity(param:object) {
    await organizationalLifeModel.create(param);
}


/**
 * 获取活动详情
 * @param id id 唯一标识
 * @returns 
 */
export async function findEventDetails(oId:number) {
    return await organizationalLifeModel.findOne({oId});
}


/**
 * 删除组织生活活动
 * @param oId 活动id
 * @returns 
 */
export async function deleteActivity(oId:number) {
    return await organizationalLifeModel.deleteOne({oId}).exec();
}


/**
 * 获取符合条件的组织生活活动数量
 * @param param 查询参数
 * @returns number 数据数量
 */
 export async function groupFindActivityCount(param:object) {
    return await organizationalLifeModel.find(param).countDocuments();
}